@@ -13,7 +13,7 @@ package CGI::Simple::Cookie;
 use strict;
 use warnings;
 use vars '$VERSION';
-$VERSION = '1.17';
+$VERSION = '1.18';
 use CGI::Simple::Util qw(rearrange unescape escape);
 use overload '""' => \&as_string, 'cmp' => \&compare, 'fallback' => 1;
 
@@ -75,14 +75,14 @@ sub new {
   $class = ref( $class ) || $class;
   my (
     $name,   $value,   $path,    $domain,
-    $secure, $expires, $max_age, $httponly
+    $secure, $expires, $max_age, $httponly, $samesite
    )
    = rearrange(
     [
       'NAME', [ 'VALUE', 'VALUES' ],
       'PATH',    'DOMAIN',
       'SECURE',  'EXPIRES',
-      'MAX-AGE', 'HTTPONLY'
+      'MAX-AGE', 'HTTPONLY', 'SAMESITE'
     ],
     @params
    );
@@ -98,6 +98,7 @@ sub new {
   $self->expires( $expires )   if defined $expires;
   $self->max_age( $expires )   if defined $max_age;
   $self->httponly( $httponly ) if defined $httponly;
+  $self->samesite( $samesite ) if defined $samesite;
   return $self;
 }
 
@@ -107,12 +108,13 @@ sub as_string {
   my $name   = escape( $self->name );
   my $value  = join "&", map { escape( $_ ) } $self->value;
   my @cookie = ( "$name=$value" );
-  push @cookie, "domain=" . $self->domain   if $self->domain;
-  push @cookie, "path=" . $self->path       if $self->path;
-  push @cookie, "expires=" . $self->expires if $self->expires;
-  push @cookie, "max-age=" . $self->max_age if $self->max_age;
-  push @cookie, "secure"                    if $self->secure;
-  push @cookie, "HttpOnly"                  if $self->httponly;
+  push @cookie, "domain=" . $self->domain     if $self->domain;
+  push @cookie, "path=" . $self->path         if $self->path;
+  push @cookie, "expires=" . $self->expires   if $self->expires;
+  push @cookie, "max-age=" . $self->max_age   if $self->max_age;
+  push @cookie, "secure"                      if $self->secure;
+  push @cookie, "HttpOnly"                    if $self->httponly;
+  push @cookie, "SameSite=" . $self->samesite if $self->samesite;
   return join "; ", @cookie;
 }
 
@@ -179,6 +181,14 @@ sub httponly {
   return $self->{'httponly'};
 }
 
+my %_legal_samesite = ( Strict => 1, Lax => 1 );
+sub samesite {
+    my $self = shift;
+    my $samesite = ucfirst lc +shift if @_; # Normalize casing.
+    $self->{'samesite'} = $samesite if $samesite and $_legal_samesite{$samesite};
+    return $self->{'samesite'};
+}
+
 1;
 
 __END__
@@ -268,7 +278,7 @@ that all scripts at your site will receive the cookie.
 If the "secure" attribute is set, the cookie will only be sent to your
 script if the CGI request is occurring on a secure channel, such as SSL.
 
-=item B<4. HttpOnly flag>
+=item B<5. HttpOnly flag>
 
 If the "httponly" attribute is set, the cookie will only be accessible
 through HTTP Requests. This cookie will be inaccessible via JavaScript
@@ -278,16 +288,26 @@ See this URL for more information including supported browsers:
 
 L<http://www.owasp.org/index.php/HTTPOnly>
 
+=item B<6. samesite flag>
+
+Allowed settings are C<Strict> and C<Lax>.
+
+As of April 2018, support is limited mostly to recent releases of
+Chrome and Opera.
+
+L<https://tools.ietf.org/html/draft-west-first-party-cookies-07>
+
 =back
 
 =head2 Creating New Cookies
 
     $c = CGI::Simple::Cookie->new( -name    =>  'foo',
-                                  -value   =>  'bar',
-                                  -expires =>  '+3M',
-                                  -domain  =>  '.capricorn.com',
-                                  -path    =>  '/cgi-bin/database',
-                                  -secure  =>  1
+                                  -value    =>  'bar',
+                                  -expires  =>  '+3M',
+                                  -domain   =>  '.capricorn.com',
+                                  -path     =>  '/cgi-bin/database',
+                                  -secure   =>  1,
+                                  -samesite =>  'Lax',
                                 );
 
 Create cookies from scratch with the B<new> method.  The B<-name> and
@@ -323,6 +343,9 @@ cookie only when a cryptographic protocol is in use.
 B<-httponly> if set to a true value, the cookie will not be accessible
 via JavaScript.
 
+B<-samesite> may be C<Lax> or C<Strict> and is an evolving part of the
+standards for cookies. Please refer to current documentation regarding it.
+
 =head2 Sending the Cookie to the Browser
 
 Within a CGI script you can send a cookie to the browser by creating
